﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace StandardWeightCalculator
{
    enum BMI { Underweight, Normal, Overweight, Obesity };

    class Calculator : Person
    {
        // GetNormalWeight 메소드는 남/녀별 신장대비 표준체중을 계산
        // 남자표준체중 = 신장(m) x 신장(m) x 22
        // 여자표준체중 = 신장(m) x 신장(m) x 21
        public float GetNormalWeight()
        {
            if (Gender == Gender.Male)
                return Height * Height * 22 * 0.0001f;
            return Height * Height * 21 * 0.0001f;
        }

        // GetBMI 메소드는 기준에 근거하여 "저체중, 정상, 과체중, 비만"를 판별하여 BMI 타입으로 반환
        // BMI = 체중(kg)/신장^2(m^2)
        // 20미만 저체중(Underweight)
        // 20~24 정상(Normal)
        // 25~29 과체중(Overweight)
        // 30이상 비만(Obesity)
        public BMI GetBMI()
        {
            float bmi = Weight / (Height * 0.01f) / (Height * 0.01f);
            Console.WriteLine("bmi=" + bmi);
            if (bmi < 20.0)
                return BMI.Underweight;
            else if (bmi >= 20.0 && bmi < 24.0)
                return BMI.Normal;
            else if (bmi >= 24.0 && bmi < 30.0)
                return BMI.Overweight;
            return BMI.Obesity;
        }

        // 한국인 하루권장섭취량 남성 2600 kcal 여성 2100 kcal
        // 기초대사량산출공식 (Herris Benedict Equation)
        // 기초대사량(남성) = 66.47 + (13.75*weight) + (5*height) - (6.76*age)
        // 기초대사량(여성) = 655.1 + (9.05*weight) + (1.85*height) - (4.68*age)
        // 활동대사량 = 저활동적(1.3)/중간활동적(1.5)/활동적(1.75)
        // 개인별 하루권장섭취량(kcal) = 기초대사량 * 활동대사량
        public float GetDailyCaloricIntake()
        {
            float activityCalory = 1.0f;
            if (Activity == Activity.Low)
                activityCalory = 1.3f;
            else if (Activity == Activity.Medium)
                activityCalory = 1.5f;
            else
                activityCalory = 1.75f;

            if (Gender == Gender.Male)
                return (66.47f + (13.75f * Weight) + (5.0f * Height) - (6.76f * Age)) * activityCalory;
            return (655.1f + (9.05f * Weight) + (1.85f * Height) - (4.68f * Age)) * activityCalory;
        }

        public override void Print()
        {
            base.Print();
            Console.WriteLine("Person 표준체중={0}", GetNormalWeight());
            Console.WriteLine("Person 비만도={0}", GetBMI());
            Console.WriteLine("Person 하루권장섭취량={0}", GetDailyCaloricIntake());
        }

        // System.Object.ToString method override
        public override string ToString()
        {
            return string.Format("{0}\nPerson 표준체중={1}\nPerson 비만도={2}\nPerson 하루권장섭취량={3}", base.ToString(), GetNormalWeight(), GetBMI(), GetDailyCaloricIntake()); // 출력
        }
    }
}
